@@ -205,6 +205,29 @@ def slide_no_by_text(pdf_file, text):
     return -1
     # raise Exception()
 
+def read_file_xenc(doc):
+    def rfile(doc, encoding):
+        with open(doc, 'r', encoding=encoding) as f:
+            tex = f.read()
+        return tex
+    try:
+        tex = rfile(doc, encoding="utf-8")
+    except Exception as e:
+        print("Problem reading file", doc)
+        print(e)
+        import glob
+        from chardet.universaldetector import UniversalDetector
+        detector = UniversalDetector()
+        detector.reset()
+        with open(doc, 'rb') as f:
+            detector.feed(f.read())
+        detector.close()
+        res = detector.result['encoding']
+        print("Detecting encoding with chardet...")
+        print(res)
+        tex = rfile(doc, encoding=detector.result['encoding'])
+    return tex
+
 def recursive_tex_apply(doc, fun=None, current_output=None):
     if not fun:
         def mfun(curdoc, txt, cur_out):
@@ -214,26 +237,8 @@ def recursive_tex_apply(doc, fun=None, current_output=None):
 
         fun = mfun
     if os.path.exists(doc):
-        def rfile(doc, encoding):
-            with open(doc, 'r', encoding=encoding) as f:
-                tex = f.read()
-            return tex
-        try:
-            tex = rfile(doc, encoding="utf-8")
-        except Exception as e:
-            print("Problem reading file", doc)
-            print(e)
-            import glob
-            from chardet.universaldetector import UniversalDetector
-            detector = UniversalDetector()
-            detector.reset()
-            with open(doc, 'rb') as f:
-                detector.feed(f.read())
-            detector.close()
-            res = detector.result['encoding']
-            print("Detecting encoding with chardet...")
-            print(res)
-            tex = rfile(doc, encoding=detector.result['encoding'])
+        tex = read_file_xenc(doc)
+
 
         current_output = fun(doc, tex, current_output)
         for s in tex.splitlines():
